@@ -4,6 +4,7 @@
 #'    \code{.name} are defined.
 #' @param ... Named arguments of lists with equal length. The names of the
 #'    lists are available as symbols that represent the element for each list.
+#' @param envir The environment to evaluate mapping function
 #' @name list.maps
 #' @export
 #' @examples
@@ -12,9 +13,8 @@
 #' l2 <- list(2,3,5)
 #' list.maps(a$x*b+a$y,a=l1,b=l2)
 #' }
-list.maps <- function(expr,...) {
+list.maps <- function(expr,...,envir = parent.frame()) {
   expr <- substitute(expr)
-  enclos <- parent.frame()
   lists <- list(...)
   if(length(lists) == 0L) return(list())
   lens <- vapply(lists,length,integer(1L))
@@ -22,6 +22,6 @@ list.maps <- function(expr,...) {
   list1 <- lists[[1L]]
   xnames <- getnames(list1)
   do.call(Map, c(function(...) {
-    eval(expr,list(...),enclos)
+    eval(expr,list(...),envir)
   },list(...),.i=list(seq_along(list1)),.name=list(xnames)))
 }
