@@ -8,6 +8,7 @@
 #' is \code{NULL}.
 #' @param prob A \code{vector} of probability weights for
 #' obtaining the elements of the list being sampled.
+#' @param envir The environment to evaluate mapping function
 #' @name list.sample
 #' @export
 #' @examples
@@ -17,9 +18,11 @@
 #' list.rbind(x)
 #' list.rbind(df)
 #' }
-list.sample <- function(.data,size,replace=FALSE,weight=1,prob=NULL) {
+list.sample <- function(.data,size,replace=FALSE,weight=1,prob=NULL,
+  envir = parent.frame()) {
   if(is.null(prob)) {
-    ws <- unlist(list.map.internal(.data,substitute(weight)),use.names = FALSE)
+    ws <- unlist(list.map.internal(.data,substitute(weight),envir = envir),
+      use.names = FALSE)
     if(any(ws<0)) stop("Negative weight is not allowed")
     prob <- ws / sum(ws)
   }
